<?php

class formSmcaptchaOptions extends cmsForm {

    public function init() {

        $themes = [];

        $config = cmsConfig::getInstance();

        $themes_dir = 'templates/' . $config->template . '/images/smcaptcha/';

        $empty_options = ['basic_options' => [
            'type'   => 'fieldset',
            'title'  => sprintf(LANG_SMCAPTCHA_DIR_EMPTY, $themes_dir),
            'childs' => [
                new fieldHidden('dir_empty')
            ]
        ]];

        if (!is_readable($themes_dir)){
            return $empty_options;
        }

        $dirs = cmsCore::getDirsList($themes_dir, true);

        if (!$dirs){
            return $empty_options;
        }

        foreach ($dirs as $dir) {
            $themes[$dir] = cmsCore::getFilesList($themes_dir . $dir);
        }

        $form_options = [

            'basic_options' => [
                'type'   => 'fieldset',
                'title'  => LANG_BASIC_OPTIONS,
                'childs' => [

                    new fieldHidden('themes_dir', [
                        'default' => $themes_dir
                    ]),

                    new fieldList('theme', [
                        'title' => LANG_SMCAPTCHA_SKIN,
                        'items' => array_combine(array_keys($themes), array_keys($themes))
                    ])

                ]

            ],

            'names' => [
                'type'   => 'fieldset',
                'title'  => LANG_SMCAPTCHA_BASIC_OPTIONS,
                'childs' => []
            ]

        ];

        $template = cmsTemplate::getInstance();

        foreach ($themes as $dir => $files) {

            if (!$files) {
                $form_options['names']['childs'][] = new fieldCheckbox('dir_empty:' . $dir, [
                    'title' => sprintf(LANG_SMCAPTCHA_DIR_EMPTY, $themes_dir . $dir),
                    'visible_depend' => ['theme' => ['show' => [$dir]]]
                ]);
                continue;
            }

            $template->addBottom('<script>$(function() { icms.modal.bindGallery(".img-sm-' . $dir . '"); });</script>');

            $form_options['names']['childs'][] =new fieldString('width:' . $dir, [
                'title'   => LANG_SMCAPTCHA_WIDTH,
                'default' => '3rem',
                'visible_depend' => ['theme' => ['show' => [$dir]]]
            ]);

            $form_options['names']['childs'][] = new fieldString('height:' . $dir, [
                'title'   => LANG_SMCAPTCHA_HEIGHT,
                'visible_depend' => ['theme' => ['show' => [$dir]]]
            ]);

            $form_options['names']['childs'][] = new fieldString('class:' . $dir, [
                'title'   => LANG_SMCAPTCHA_CSS,
                'visible_depend' => ['theme' => ['show' => [$dir]]]
            ]);

            foreach ($files as $file) {

                $img_src = '/' . $themes_dir . $dir . '/' . $file;

                $form_options['names']['childs'][] = new fieldString('names:' . $dir . ':' . pathinfo($file, PATHINFO_FILENAME), [
                    'title' => LANG_SMCAPTCHA_NAME_FOR . $file,
                    'prefix' => '<a class="img-sm-' . $dir . '" title="' . $file . '" href="' . $config->host . $img_src . '"><img class="img-fluid" style="max-width: 18px; max-height: 18px;" src="' . $img_src . '"></a>',
                    'visible_depend' => ['theme' => ['show' => [$dir]]]
                ]);

            }

        }

        return $form_options;

    }

}
